]> Git Repo - qemu.git/blobdiff - hw/qdev.h
malta: Fix regression (i8259 interrupts did not work)
[qemu.git] / hw / qdev.h
index 42495aed04cbe933d105644309193e43398de299..2abb7673890ab2a9462135528180d4f30b624d48 100644 (file)
--- a/hw/qdev.h
+++ b/hw/qdev.h
@@ -156,6 +156,7 @@ enum PropertyType {
 
 struct PropertyInfo {
     const char *name;
+    const char *legacy_name;
     size_t size;
     enum PropertyType type;
     int64_t min;
@@ -486,11 +487,10 @@ const char *qdev_property_get_type(DeviceState *dev, const char *name,
                                    Error **errp);
 
 /**
* @qdev_property_add_legacy - add a legacy @Property to a device
*
* DO NOT USE THIS IN NEW CODE!
  */
-void qdev_property_add_legacy(DeviceState *dev, Property *prop, Error **errp);
+void qdev_property_add_static(DeviceState *dev, Property *prop, Error **errp);
 
 /**
  * @qdev_get_root - returns the root device of the composition tree
@@ -616,4 +616,12 @@ void qdev_property_add_str(DeviceState *dev, const char *name,
  */
 char *qdev_get_type(DeviceState *dev, Error **errp);
 
+/**
+ * @qdev_machine_init
+ *
+ * Initialize platform devices before machine init.  This is a hack until full
+ * support for composition is added.
+ */
+void qdev_machine_init(void);
+
 #endif
This page took 0.025952 seconds and 4 git commands to generate.
@@ -486,11 +487,10 @@ const char *qdev_property_get_type(DeviceState *dev, const char *name,
 
 /**
- * @qdev_property_add_legacy - add a legacy @Property to a device
- *
- * DO NOT USE THIS IN NEW CODE!
+ * @qdev_property_add_static - add a @Property to a device referencing a
+ * field in a struct.
  */